helm

package
v0.11.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 20, 2026 License: Apache-2.0 Imports: 18 Imported by: 0

Documentation

Index

Constants

const (
	HelmMajorVersion3 = 3
	HelmMajorVersion4 = 4
)

Variables

This section is empty.

Functions

func CreateChartPackage

func CreateChartPackage(c *Chart, outDir string) (string, error)

CreateChartPackage creates a new .tgz package in directory

Types

type Chart

type Chart struct {
	Metadata *Metadata
	// contains filtered or unexported fields
}

Chart is a helm package that contains metadata

func GetChartByName

func GetChartByName(name string) (*Chart, error)

GetChartByName returns a chart by "name", which can be either a directory or .tgz package

func (*Chart) GetMetadata added in v0.11.0

func (c *Chart) GetMetadata() *Metadata

GetMetadata returns the chart metadata

func (*Chart) SetAppVersion

func (c *Chart) SetAppVersion(appVersion string)

SetAppVersion overrides the app version

func (*Chart) SetVersion

func (c *Chart) SetVersion(version string)

SetVersion overrides the chart version

type HelmMajorVersion

type HelmMajorVersion int

func HelmMajorVersionCurrent

func HelmMajorVersionCurrent() HelmMajorVersion

type Index

type Index struct {
	ServerInfo ServerInfo `json:"serverInfo"`
	// contains filtered or unexported fields
}

Index represents the index file in a chart repository

func GetIndexByDownloader

func GetIndexByDownloader(downloadIndex IndexDownloader, version HelmMajorVersion) (*Index, error)

GetIndexByDownloader takes binary data from IndexDownloader and returns an Index object

func GetIndexByRepo

func GetIndexByRepo(repo *Repo, downloadIndex IndexDownloader) (*Index, error)

GetIndexByRepo returns index by repository

func LoadIndex

func LoadIndex(data []byte, version HelmMajorVersion) (*Index, error)

LoadIndex loads an index file

func (*Index) SortEntries added in v0.11.0

func (i *Index) SortEntries()

SortEntries sorts entries in the index

type IndexDownloader

type IndexDownloader func() ([]byte, error)

IndexDownloader is a function to download the index

type Metadata added in v0.11.0

type Metadata struct {
	Name       string
	Version    string
	AppVersion string
}

Metadata returns a unified metadata view

type Repo

type Repo struct {
	// contains filtered or unexported fields
}

Repo represents a collection of parameters for chart repository

func GetRepoByName

func GetRepoByName(name string) (*Repo, error)

GetRepoByName returns repository by name

func TempRepoFromURL

func TempRepoFromURL(url string) (*Repo, error)

TempRepoFromURL builds a temporary Repo from a given URL

func (*Repo) GetCachePath added in v0.11.0

func (r *Repo) GetCachePath() string

func (*Repo) GetConfigName added in v0.11.0

func (r *Repo) GetConfigName() string

Accessor methods for Config fields

func (*Repo) GetConfigPassword added in v0.11.0

func (r *Repo) GetConfigPassword() string

func (*Repo) GetConfigURL added in v0.11.0

func (r *Repo) GetConfigURL() string

func (*Repo) GetConfigUsername added in v0.11.0

func (r *Repo) GetConfigUsername() string

type ServerInfo

type ServerInfo struct {
	ContextPath string `json:"contextPath"`
}

ServerInfo describes the server information

Jump to